@@ -80,6 +80,7 @@ void       MirrorCallback(PAUL *p, int which);
 void       MonochromeCallback(PAUL *p, int which);
 void       NegativCallback(PAUL *p, int which);
 void       RotateCallback(PAUL *p, int which);
+void       RotateVariableCallback(PAUL *p, int which);
 void       ShrinkCallback(PAUL *p, int which);
 
 /* gcutarea.c */
@@ -144,6 +145,7 @@ void       DifferenceParameterCallback(PAUL *p);
 void       FilterParameterCallback(PAUL *p);
 void       GrayParameterCallback(PAUL *p);
 void       MoveParameterCallback(PAUL *p);
+void       RotationParameterCallback(PAUL *p);
 void       ScaleParameterCallback(PAUL *p);
 void       ShrinkParameterCallback(PAUL *p);
 
