@@ -8,7 +8,7 @@
  *            Funktions to cut rectangular areas from an image               *
  * Author:    Andreas Tille                                                  *
  * Date:      27.02.1998                                                     *
- * Copyright: Andreas Tille, 1999; Gnu Public License                        *
+ * Copyright: Andreas Tille, 1999; GNU Public License                        *
  *                                                                           *
  *****************************************************************************/
 
@@ -18,6 +18,33 @@
 
 #include "paul.h" 
 
+guchar *_CropImageData(guchar *image, gint width, gint x, gint y, gint w, gint h, gchar storepix)
+/* Here the actual cropping is done ... just needed in the rotating function
+ * no testing of valid crop coordinates is done
+ * guchar image   : image pixel data
+ * gint   width   : original width
+ * gint   x       : x coordinate of starting point
+ * gint   y       : y coordinate of starting point
+ * gint   w       : new width
+ * gint   h       : new height
+ * gchar  storepix: number of bytes representing one pixel
+ */
+{
+  register unsigned char *ap, *bp, *fap;
+  register int            sw, sW;
+  guchar  *data;
+   
+  sw   = storepix * w;
+  sW   = storepix * width;
+  data = g_malloc(sw*h);
+  
+  for ( fap = (ap = image + storepix*(y*width + x)) + h*sW,
+        bp  = data; ap < fap; ap += sW, bp += sw )
+    memcpy(bp, ap, sw);
+  g_free(image);
+  return data;
+}
+
 int CropImage(PICTURE *bild, int x, int y, int w, int h)
 /* Implements an own crop routine if images has to be cut before ImLib structures
  * are created.  After creation of ImLib structures it is necessary to use the
@@ -33,34 +60,33 @@ int CropImage(PICTURE *bild, int x, int y, int w, int h)
  * int      CropImage(): RET_ERR in case of error, else RET_OK
  */
 {
-  register unsigned char *ap, *bp, *fap;
-  register int            sw, sW;
-  unsigned char          *data;
-
   g_return_val_if_fail ( IS_PICTURE(bild), RET_ERR );
+
+  if ( w > bild->W - x ) 
+    g_warning(_("New width exceeds image size.  Cropped to %i."), w = bild->W - x);
+  if ( h > bild->H - y ) 
+    g_warning(_("New height exceeds image size.  Cropped to %i."), h = bild->H - y);
+
   if ( x < 0 || y < 0 ) {
     g_warning(_("Invalid top-left cutting point (%i,%i)"), x, y);
     return RET_ERR;
   }
+
+  if ( w <= 0 || h <= 0 ) {
+    g_warning(_("Invalid cutting dimensions (%ix%i)"), w, h);
+    return RET_ERR;
+  }
   if ( w > bild->W || h > bild->H ) {
     g_warning(_("Invalid bottom-rigth cutting point (%i,%i)"), w, h);
     return RET_ERR;
   }
 
   if ( bild->im ) {
-     gdk_imlib_crop_image(bild->im, x, y, w, h);
-     bild->DATA = bild->im->rgb_data;
-  } else {
-    sw   = bild->storepix * w;
-    sW   = bild->storepix * bild->W;
-    data = g_malloc(sw*h);
-  
-    for ( fap = (ap = bild->DATA + bild->storepix*(y*bild->W + x)) + h*sW,
-          bp  = data; ap < fap; ap += sW, bp += sw )
-      memcpy(bp, ap, sw);
-    FREE(bild->DATA);
-    bild->DATA = data;
-  }
+    gdk_imlib_crop_image(bild->im, x, y, w, h);
+    bild->DATA = bild->im->rgb_data;
+  } else 
+    bild->DATA = _CropImageData(bild->DATA, bild->W, x, y, w, h, bild->storepix);
+
   bild->size = (bild->W = w) * (bild->H = h);
 
   return RET_OK;
