@@ -12,7 +12,9 @@
  *                                                                           *
  *****************************************************************************/
 
+#ifdef HAVE_DATABOX 
 #include <gtkdatabox.h>
+#endif
 
 #include "paul.h" 
 
@@ -26,9 +28,11 @@
 #define RADIUS(i, j)          sqrt((i)*(i) + (j)*(j))
 
 #include <math.h>
-#include <rfftw.h>
+#include <srfftw.h>
 
+#ifdef HAVE_DATABOX 
 static int ShowFFTProfile(GList *piclist);
+#endif
 
 int FastFourierTransform(PAUL *p)
 /* calculate fast fourier transforms of images
@@ -135,13 +139,16 @@ int FastFourierTransform(PAUL *p)
     ImgChunksUpdate(bild, TypFFT, desc, APPFFT, FFT);
     FREE(desc);
   }
+#ifdef HAVE_DATABOX 
   if ( p->filelist ) ShowFFTProfile(p->piclist);
+#endif
   
   p->opt->f  &= ~FFT;
    
   return RET_OK;
 }
 
+#ifdef HAVE_DATABOX 
 static int ShowFFTProfile(GList *piclist)
 /* display radial FFT profile of all images in piclist
  * --- Parameter: ---
@@ -216,6 +223,7 @@ static int ShowFFTProfile(GList *piclist)
 
   return RET_OK;
 }
+#endif /* Do not show FFT profile if libgtkdatabox does not exist */
  
 #else
 
