@@ -11,7 +11,9 @@
  *                                                                           *
  *****************************************************************************/
 
+#ifdef HAVE_DATABOX
 #include <gtkdatabox.h>
+#endif
 
 #include "paul.h"
 
@@ -169,6 +171,7 @@ int ShowHistograms(GList *piclist)
  * int    ShowHistograms() : RET_ERR or RET_OK
  */
 {
+#ifdef HAVE_DATABOX /* No graphical display if libgtkdtabox does not exist */
 #define HIST_POINTS 256
   static GtkWidget *window = NULL;
   GtkWidget        *curve;
@@ -250,5 +253,6 @@ int ShowHistograms(GList *piclist)
 
   return RET_OK;
 #undef HIST_POINTS
+#endif
 }
  
