@@ -237,3 +237,33 @@ void ShrinkParameterCallback(PAUL *p)
     BuildParameterInput(table, Shrink, Shrink_p, para, 
                         GTK_SIGNAL_FUNC(_ParameterChanged), table, NULL, NULL);
 }
+
+/*****************************************************************************************
+ * rotation angle input                                                                  *
+ *****************************************************************************************/
+
+void RotationParameterCallback(PAUL *p)
+{
+  ITEM      *para;
+  GtkWidget *table;
+  int        np = 1;
+   
+  para           = g_new0(ITEM, np+1);
+  para->name     = _("Rotation angle []:");
+  para->typ      = P_DOUBLE;
+  while ( p->opt->angle >  360.0 ) p->opt->angle -= 360.0;
+  while ( p->opt->angle <    0.0 ) p->opt->angle += 360.0;
+  para->val      = &(p->opt->angle);
+  para->upper    = 360.0;
+  para->lower    = 0.0;
+  para->valchg   = NULL;
+  para->adj      = NULL;
+  para->userdata = NULL;
+   
+  if ( (table = BuildParameterTable(para, np)) )
+    BuildParameterInput(table, Rotation_p, Rotation_d, para, 
+                        GTK_SIGNAL_FUNC(_ParameterChanged), table, NULL, NULL);
+}
+
+
+
