@@ -3,11 +3,11 @@
  * Program:   paul                                                           *
  *            (P)rogramm zur (A)uswertung und (U)mformung von                *
  *            (L)aserbildern                                                 *
- * Uses:      GTK+ 1.2, Imlib                                                *
+ * Uses:      GTK+ 1.2, Imlib, GtkImReg                                      *
  * Modul:     paul.c (main)                                                  *
  * Author:    Andreas Tille                                                  *
  * Date:      18.02.1998                                                     *
- * Copyright: Andreas Tille, 1999; GNU Public License                        *
+ * Copyright: Andreas Tille, 1999, 2000, 2001, 2002; GNU Public License      *
  *                                                                           *
  *****************************************************************************/
 
@@ -16,6 +16,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <ctype.h>
 #include <locale.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -66,6 +67,7 @@ int usage(void)
   fputs(_("-z[i]           shrink i levels (1 level means = half the width and half the height)\n"),
         stderr);
   fputs(_("-F              calculate fast fourier transform of image\n"), stderr);
+  fputs(_("-G              don't make _G_ray images green\n"), stderr);
   fputs(_("-H              print this _H_elp screen\n"), stderr);
   return RET_ERR;
 }
@@ -85,6 +87,8 @@ int main(int argc, char **argv)
   OPTIONS        popt;
   int            i;                 /* counter for different purposes                        */
   register char *mp;                /* helping pointer                                       */
+  GList         *pl;
+  PICTURE       *bild;
 
   const char *cutorext;
   cutorext = _("Search for extrema and cut image isn't possible at the same time.");
@@ -125,13 +129,16 @@ int main(int argc, char **argv)
   popt.xi     =  popt.yi = -1;      /* coordinates for image to insert         */
   popt.bright = NULL;               /* no brightness file                      */
   popt.html   =  popt.link = NULL;  /* no HTML output and no link by default   */
+  popt.angle  =  0.0;               /* rotation angle                          */
   popt.sek    = -1.0;               /* animation delay time between two images */
   popt.scale  =  1.0;               /* factor for contrast                     */
+  /* if the program name is "gaul" turn gray images into green images for display */
+  if ( strcmp(exename, "gaul") ) popt.f |= DISPLAYGRAY;
 
 /*************************************************************************************
  * Read options                                                                      *
  *************************************************************************************/   
-  while ( (i = getopt(argc, argv, "a:b::c:d::e:f::g::hi::j:mno::p:qr::st:w::z::FH")) != EOF )
+  while ( (i = getopt(argc, argv, "a:b::c:d::e:f::g::hi::j:mno::p:qr::st:w::z::FGH")) != EOF )
     switch (i) {
       case 'a': 
         { register char *pp;
@@ -245,7 +252,11 @@ int main(int argc, char **argv)
 	    if ( *bp ) popt.link = g_strdup(bp);
 	  }
 	  
-          if ( !(paul.op = ReadPic(ap, NULL)) ) return usage();
+          if ( !(pl = ReadPic(ap, NULL)) ) return usage();
+          if ( !(paul.op = BILD(pl)) ) return usage();
+          if ( (bild = BILD(pl = pl->next)) )
+            for ( ; pl; bild = BILD(pl = pl->next) )
+              paul.piclist = g_list_append(paul.piclist, bild);
         }
         break;
       case 'm':
@@ -289,11 +300,13 @@ int main(int argc, char **argv)
         popt.f |= DELSCANBORDER;
         break;
       case 't':
-        if ( !optarg || sscanf(optarg, "%i", &i) != 1 ) return usage();
-        if      ( i ==  90 ) popt.f |= ROT_90;
-        else if ( i == 180 ) popt.f |= ROT_180;
-        else if ( i == 270 ) popt.f |= (ROT_90 | ROT_180);
-        else return usage();
+        if ( !optarg || sscanf(optarg, "%lg", &(popt.angle)) != 1 ) return usage();
+        while ( popt.angle >  360.0 ) popt.angle -= 360.0;
+        while ( popt.angle <    0.0 ) popt.angle += 360.0;
+        if      ( fabs(popt.angle -  90) < 1e-6 ) popt.f |= ROT_90;
+        else if ( fabs(popt.angle - 180) < 1e-6 ) popt.f |= ROT_180;
+        else if ( fabs(popt.angle - 270) < 1e-6 ) popt.f |= (ROT_90 | ROT_180);
+        else popt.f |= ROTVAR;
         break;
       case 'w':
         if ( !optarg ) { popt.sek = 0; break; }
@@ -308,6 +321,9 @@ int main(int argc, char **argv)
       case 'F':
         popt.f |= FFT;
         break;
+      case 'G':
+        popt.f |= DISPLAYGRAY;
+        break;
       case '?':
         g_warning("%s", optarg);
       case 'H':
@@ -331,9 +347,9 @@ int main(int argc, char **argv)
 /*************************************************************************************
  * Read images                                                                       *
  *************************************************************************************/   
-  paul.piclist = ReadPicFiles(argc - optind, argv + optind, &popt);
+  paul.piclist = ReadPicFiles(paul.piclist, argc - optind, argv + optind, &popt);
   paul.opt = &popt;
- 
+
   if ( !(paul.piclist) && (paul.opt->f & QUIET) ) {
     g_warning(_("No files preloaded")); 
     PaulExit(&paul);
