@@ -162,7 +162,10 @@ int PaulLoadPNG(PICTURE *bild, FILE *fp, long flag, int *read_anything)
     
     for ( fip = (ap = bild->data) + 3*bild->size, ap++; ap < fip; ) {
       png_read_row(png_ptr, ptr, NULL);
-      for ( fpp = (pp = ptr) + bild->W; pp < fpp; pp++, ap += 3 ) *ap = *pp;
+      if ( DisplayGray(flag) )
+        for ( fpp = (pp = ptr) + bild->W; pp < fpp; pp++, ap += 3 ) *ap = *(ap-1) = *(ap+1) = *pp;
+      else
+        for ( fpp = (pp = ptr) + bild->W; pp < fpp; pp++, ap += 3 ) *ap = *pp;
       ++*read_anything;
     }
     FREE(ptr);
